@@ -47,15 +47,15 @@ def execute(
 		error_, output = error.stderr, error.output
 		if isinstance(error_, bytes): error_ = error_.decode()
 		if isinstance(output, bytes): output = error_.decode()
-		return r3sponse.error_response(f"Failed to execute command ({command}), (output: {output}), (error: {error_}).")
+		return r3sponse.error(f"Failed to execute command ({command}), (output: {output}), (error: {error_}).")
 	error_, output = proc.stderr, proc.stdout
 	if isinstance(error_, bytes): error_ = error_.decode()
 	if isinstance(output, bytes): output = error_.decode()
 	if error_ != "":
-		return r3sponse.error_response(f"Failed to execute command ({command}), (output: {output}), (error: {error_}).")
+		return r3sponse.error(f"Failed to execute command ({command}), (output: {output}), (error: {error_}).")
 	if len(output) > 0 and output[len(output)-1] == "\n": output = output[:-1]
 	Files.delete(path)
-	return r3sponse.success_response(f"Succesfully executed command ({command}), (output: {output}), (error: {error_}).", {
+	return r3sponse.success(f"Succesfully executed command ({command}), (output: {output}), (error: {error_}).", {
 		"output":output,
 		"pid":process.pid,
 		"process":proc,
